Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/st7789_simpletest.py
    :caption: examples/st7789_simpletest.py
    :linenos:

240x135
=======

.. literalinclude:: ../examples/st7789_240x135_simpletest.py
    :caption: examples/st7789_240x135_simpletest.py
    :linenos:

280x240
=======

.. literalinclude:: ../examples/st7789_280x240_simpletest.py
    :caption: examples/st7789_280x240_simpletest.py
    :linenos:

320x240
=======

.. literalinclude:: ../examples/st7789_320x240_simpletest.py
    :caption: examples/st7789_320x240_simpletest.py
    :linenos:

Product specific examples
-------------------------

1.14" Mini PiTFT
================

.. literalinclude:: ../examples/st7789_240x135_pitft_simpletest.py
    :caption: examples/st7789_240x135_pitft_simpletest.py
    :linenos:

1.3" TFT Bonnet
===============

.. literalinclude:: ../examples/st7789_240x240_bonnet_simpletest.py
    :caption: examples/st7789_240x240_bonnet_simpletest.py
    :linenos:

1.3" PiTFT
==========

.. literalinclude:: ../examples/st7789_240x240_pitft_simpletest.py
    :caption: examples/st7789_240x240_pitft_simpletest.py
    :linenos:

Gizmo
=====

.. literalinclude:: ../examples/st7789_tft_gizmo_simpletest.py
    :caption: examples/st7789_tft_gizmo_simpletest.py
    :linenos:

Pimoroni Pico Display Pack
==========================

.. literalinclude:: ../examples/st7789_240x135_simpletest_Pimoroni_Pico_Display_Pack.py
    :caption: examples/st7789_240x135_simpletest_Pimoroni_Pico_Display_Pack.py
    :linenos:

Pimoroni Pico Explorer
======================

.. literalinclude:: ../examples/st7789_240x240_simpletest_Pimoroni_Pico_Explorer.py
    :caption: examples/st7789_240x240_simpletest_Pimoroni_Pico_Explorer.py
    :linenos:

Pimoroni Pico Display Pack 2.0
==============================

.. literalinclude:: ../examples/st7789_320x240_simpletest_Pimoroni_Pico_Display_2_0.py
    :caption: examples/st7789_320x240_simpletest_Pimoroni_Pico_Display_2_0.py
    :linenos:
